@@ -99,6 +99,7 @@ EXTENSIONS = {
     'js': {'text', 'javascript'},
     'json': {'text', 'json'},
     'jsonnet': {'text', 'jsonnet'},
+    'json5': {'text', 'json5'},
     'jsx': {'text', 'jsx'},
     'key': {'text', 'pem'},
     'kml': {'text', 'kml', 'xml'},
@@ -162,6 +163,7 @@ EXTENSIONS = {
     'pyx': {'text', 'cython'},
     'pyz': {'binary', 'pyz'},
     'pyzw': {'binary', 'pyz'},
+    'qml': {'text', 'qml'},
     'r': {'text', 'r'},
     'rake': {'text', 'ruby'},
     'rb': {'text', 'ruby'},
